@@ -146,40 +146,22 @@ FreeBusyManagerPrivate::FreeBusyProviderRequest::FreeBusyProviderRequest(const Q
 
 /// FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue
 
-FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue(
-    const QString &start, const QString &end)
+FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue()
     : mHandlersCount(0), mResultingFreeBusy(nullptr)
 {
-    KDateTime startDate, endDate;
-
-    if (!start.isEmpty()) {
-        mStartTime = start;
-        startDate = KDateTime::fromString(start);
-    } else {
-        // Set the start of the period to today 00:00:00
-        startDate = KDateTime(KDateTime::currentLocalDate());
-        mStartTime = startDate.toString();
-    }
-
-    if (!end.isEmpty()) {
-        mEndTime = end;
-        endDate = KDateTime::fromString(end);
-    } else {
-        // Set the end of the period to today + 14 days.
-        endDate = KDateTime(KDateTime::currentLocalDate()).addDays(14);
-        mEndTime = endDate.toString();
-    }
-
-    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(startDate, endDate));
+    // Set the start of the period to today 00:00:00
+    mStartTime = QDateTime(QDate::currentDate(), QTime());
+    mEndTime = mStartTime.addDays(14);
+    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KDateTime(mStartTime), KDateTime(mEndTime)));
 }
 
 FreeBusyManagerPrivate::FreeBusyProvidersRequestsQueue::FreeBusyProvidersRequestsQueue(
-    const KDateTime &start, const KDateTime &end)
+    const QDateTime &start, const QDateTime &end)
     : mHandlersCount(0), mResultingFreeBusy(nullptr)
 {
-    mStartTime = start.toString();
-    mEndTime = end.toString();
-    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(start, end));
+    mStartTime = start;
+    mEndTime = end;
+    mResultingFreeBusy = KCalCore::FreeBusy::Ptr(new KCalCore::FreeBusy(KDateTime(start), KDateTime(end)));
 }
 
 /// FreeBusyManagerPrivate
@@ -328,7 +310,8 @@ void FreeBusyManagerPrivate::contactSearchJobFinished(KJob *_job)
     QStringList::ConstIterator ext;
     QList<QUrl> urlsToCheck;
     urlsToCheck.reserve(extensions.count());
-    for (ext = extensions.constBegin(); ext != extensions.constEnd(); ++ext) {
+    QStringList::ConstIterator extEnd(extensions.constEnd());
+    for (ext = extensions.constBegin(); ext != extEnd; ++ext) {
         // build a url for this extension
         const QUrl sourceUrl = QUrl(CalendarSettings::self()->freeBusyRetrieveUrl());
         QUrl dirURL = replaceVariablesUrl(sourceUrl, email);
@@ -601,8 +584,8 @@ void FreeBusyManagerPrivate::queryFreeBusyProviders(const QStringList &providers
 
 void FreeBusyManagerPrivate::queryFreeBusyProviders(const QStringList &providers,
         const QString &email,
-        const KDateTime &start,
-        const KDateTime &end)
+        const QDateTime &start,
+        const QDateTime &end)
 {
     if (!mProvidersRequestsByEmail.contains(email)) {
         mProvidersRequestsByEmail[email] = FreeBusyProvidersRequestsQueue(start, end);
@@ -627,7 +610,8 @@ void FreeBusyManagerPrivate::onHandlesFreeBusy(const QString &email, bool handle
     qCDebug(AKONADICALENDAR_LOG) << respondingService << "responded to our FreeBusy request:" << handles;
     int requestIndex = -1;
 
-    for (int i = 0; i < queue->mRequests.size(); ++i) {
+    const int requestsSize(queue->mRequests.size());
+    for (int i = 0; i < requestsSize; ++i) {
         if (queue->mRequests.at(i).mInterface->service() == respondingService) {
             requestIndex = i;
         }
@@ -695,7 +679,8 @@ void FreeBusyManagerPrivate::onFreeBusyRetrieved(const QString &email,
     QString respondingService = iface->service();
     int requestIndex = -1;
 
-    for (int i = 0; i < queue->mRequests.size(); ++i) {
+    const int requestsSize(queue->mRequests.size());
+    for (int i = 0; i < requestsSize; ++i) {
         if (queue->mRequests.at(i).mInterface->service() == respondingService) {
             requestIndex = i;
         }
