@@ -91,7 +91,7 @@ void IncidenceChanger::Private::onCollectionsLoaded(KJob *job)
     bool noAcl = false;
     bool invalidCollection = false;
     Collection collectionToUse;
-    foreach (const Change::Ptr &change, mPendingCreations) {
+    foreach (const Change::Ptr &change, mPendingCreations) { //Don't use for(...:...) here.
         mPendingCreations.removeAll(change);
 
         if (canceled) {
@@ -189,6 +189,9 @@ void IncidenceChanger::Private::step1DetermineDestinationCollection(const Change
                                            << "isValid = "  << mDefaultCollection.isValid()
                                            << "has ACLs = " << hasRights(mDefaultCollection, ChangeTypeCreate);
         // else fallthrough, and ask the user.
+#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
+        Q_FALLTHROUGH();
+#endif
         case DestinationPolicyAsk: {
             mPendingCreations << change;
             loadCollections(); // Now we wait, collections are being loaded async
